@@ -349,21 +349,6 @@ thunar_application_startup (GApplication *gapp)
   /* initialize the application */
   application->preferences = thunar_preferences_get ();
 
-  /* TODO: how do accel maps integrate with GAction/GMenu? */
-  /* check if we have a saved accel map */
-  path = xfce_resource_lookup (XFCE_RESOURCE_CONFIG, ACCEL_MAP_PATH);
-  if (G_LIKELY (path != NULL))
-    {
-      /* load the accel map */
-      gtk_accel_map_load (path);
-      g_free (path);
-    }
-
-  /* watch for changes */
-  application->accel_map = gtk_accel_map_get ();
-  g_signal_connect_swapped (G_OBJECT (application->accel_map), "changed",
-      G_CALLBACK (thunar_application_accel_map_changed), application);
-
 #ifdef HAVE_GUDEV
   /* establish connection with udev */
   application->udev_client = g_udev_client_new (subsystems);
@@ -381,6 +366,21 @@ thunar_application_startup (GApplication *gapp)
 
   G_APPLICATION_CLASS (thunar_application_parent_class)->startup (gapp);
 
+  /* TODO: how do accel maps integrate with GAction/GMenu? Using GtkAction for now */
+  /* check if we have a saved accel map */
+  path = xfce_resource_lookup (XFCE_RESOURCE_CONFIG, ACCEL_MAP_PATH);
+  if (G_LIKELY (path != NULL))
+    {
+      /* load the accel map */
+      gtk_accel_map_load (path);
+      g_free (path);
+    }
+
+  /* watch for changes */
+  application->accel_map = gtk_accel_map_get ();
+  g_signal_connect_swapped (G_OBJECT (application->accel_map), "changed",
+      G_CALLBACK (thunar_application_accel_map_changed), application);
+
   thunar_application_load_css ();
 }
 
@@ -581,12 +581,16 @@ thunar_application_load_css (void)
 
   css_provider = gtk_css_provider_new ();
 
-                                                 /* For the pathbar-buttons any margin looks ugly*/
-  gtk_css_provider_load_from_data (css_provider, ".path-bar-button { margin-right: 0; }"
-
-                                                 /* remove extra border between side pane and view */
-                                                 ".shortcuts-pane { border-right-width: 0px; }"
-                                                 ".standard-view { border-left-width: 0px; }", -1, NULL);
+  gtk_css_provider_load_from_data (css_provider,
+    /* for the pathbar-buttons any margin looks ugly*/
+    ".path-bar-button { margin-right: 0; }"
+    /* remove extra border between side pane and view */
+    ".shortcuts-pane { border-right-width: 0px; }"
+    /* add missing top border to side pane */
+    ".shortcuts-pane { border-top-style: solid; }"
+    /* make border thicker during DnD */
+    ".standard-view { border-left-width: 0px; }"
+    ".standard-view:drop(active) { border-width: 2px; }", -1, NULL);
   screen = gdk_screen_get_default ();
   gtk_style_context_add_provider_for_screen (screen, GTK_STYLE_PROVIDER (css_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   g_object_unref (css_provider);
@@ -1233,14 +1237,15 @@ thunar_application_take_window (ThunarApplication *application,
 
 /**
  * thunar_application_open_window:
- * @application    : a #ThunarApplication.
- * @directory      : the directory to open.
- * @screen         : the #GdkScreen on which to open the window or %NULL
- *                   to open on the default screen.
- * @startup_id     : startup id from startup notification passed along
- *                   with dbus to make focus stealing work properly.
+ * @application      : a #ThunarApplication.
+ * @directory        : the directory to open.
+ * @screen           : the #GdkScreen on which to open the window or %NULL
+ *                     to open on the default screen.
+ * @startup_id       : startup id from startup notification passed along
+ *                     with dbus to make focus stealing work properly.
+ * @force_new_window : set this flag to force a new window, even if misc-open-new-window-as-tab is set
  *
- * Opens a new #ThunarWindow for @application, displaying the
+ * Opens a new #ThunarWindow (or tab if preferred) for @application, displaying the
  * given @directory.
  *
  * Return value: the newly allocated #ThunarWindow.
@@ -1249,10 +1254,13 @@ GtkWidget*
 thunar_application_open_window (ThunarApplication *application,
                                 ThunarFile        *directory,
                                 GdkScreen         *screen,
-                                const gchar       *startup_id)
+                                const gchar       *startup_id,
+                                gboolean           force_new_window)
 {
+  GList*     list;
   GtkWidget *window;
   gchar     *role;
+  gboolean   open_new_window_as_tab;
 
   _thunar_return_val_if_fail (THUNAR_IS_APPLICATION (application), NULL);
   _thunar_return_val_if_fail (directory == NULL || THUNAR_IS_FILE (directory), NULL);
@@ -1261,6 +1269,25 @@ thunar_application_open_window (ThunarApplication *application,
   if (G_UNLIKELY (screen == NULL))
     screen = gdk_screen_get_default ();
 
+  /* open as tab instead, if preferred */
+  g_object_get (G_OBJECT (application->preferences), "misc-open-new-window-as-tab", &open_new_window_as_tab, NULL);
+  if (G_UNLIKELY (!force_new_window && open_new_window_as_tab))
+    {
+      list = thunar_application_get_windows (application);
+      if (list != NULL)  
+        {
+          /* this will be the topmost Window */
+          list = g_list_last (list);
+
+          if (directory != NULL)
+              thunar_window_notebook_insert (THUNAR_WINDOW (list->data), directory);
+          
+          /* bring the window to front */
+          gtk_window_present (list->data);
+          return list->data;
+        }
+    }
+
   /* generate a unique role for the new window (for session management) */
   role = g_strdup_printf ("Thunar-%u-%u", (guint) time (NULL), (guint) g_random_int ());
 
@@ -1858,7 +1885,7 @@ thunar_application_copy_to (ThunarApplication *application,
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
 
   /* launch the operation */
-  thunar_application_launch (application, parent, "stock_folder-copy",
+  thunar_application_launch (application, parent, "edit-copy",
                              _("Copying files..."), thunar_io_jobs_copy_files,
                              source_file_list, target_file_list, new_files_closure);
 }
@@ -1899,7 +1926,7 @@ thunar_application_copy_into (ThunarApplication *application,
    g_free (display_name);
 
   /* collect the target files and launch the job */
-  thunar_application_collect_and_launch (application, parent, "stock_folder-copy",
+  thunar_application_collect_and_launch (application, parent, "edit-copy",
                                          title, thunar_io_jobs_copy_files,
                                          source_file_list, target_file,
                                          new_files_closure);
