@@ -189,7 +189,8 @@ thunar_progress_view_init (ThunarProgressView *view)
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  image = g_object_new (GTK_TYPE_IMAGE, "icon-size", GTK_ICON_SIZE_BUTTON, NULL);
+  image = g_object_new (GTK_TYPE_IMAGE, "icon-size", GTK_ICON_SIZE_DND, NULL);
+  gtk_image_set_pixel_size (GTK_IMAGE(image), 32);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
   exo_binding_new (G_OBJECT (view), "icon-name", G_OBJECT (image), "icon-name");
   gtk_widget_show (image);
@@ -227,7 +228,8 @@ thunar_progress_view_init (ThunarProgressView *view)
   gtk_box_pack_start (GTK_BOX (vbox3), view->progress_label, FALSE, TRUE, 0);
   gtk_widget_show (view->progress_label);
 
-  button = gtk_button_new ();
+  button = gtk_button_new_from_icon_name ("process-stop", GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_label (GTK_BUTTON (button), _("Cancel"));
   g_signal_connect_swapped (button, "clicked", G_CALLBACK (thunar_progress_view_cancel_job), view);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_set_can_focus (button, FALSE);
@@ -482,11 +484,12 @@ thunar_progress_view_percent (ThunarProgressView *view,
 
   /* set progress text */
   if (THUNAR_IS_TRANSFER_JOB (job))
-    {
-      text = thunar_transfer_job_get_status (THUNAR_TRANSFER_JOB (job));
-      gtk_label_set_text (GTK_LABEL (view->progress_label), text);
-      g_free (text);
-    }
+    text = thunar_transfer_job_get_status (THUNAR_TRANSFER_JOB (job));
+  else
+    text = g_strdup_printf ("%.2f%%", percent);
+
+  gtk_label_set_text (GTK_LABEL (view->progress_label), text);
+  g_free (text);
 }
 
 
