@@ -308,7 +308,7 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
   renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
                            "weight", PANGO_WEIGHT_BOLD,
                            "xpad", 6,
-                           "ypad", 6,
+                           "ypad", 4,
                            "ellipsize", PANGO_ELLIPSIZE_END,
                            NULL);
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
@@ -1661,7 +1661,7 @@ thunar_shortcuts_view_poke_file_finish (ThunarBrowser *browser,
           /* open a new window for the target folder */
           application = thunar_application_get ();
           thunar_application_open_window (application, target_file,
-                                          gtk_widget_get_screen (GTK_WIDGET (browser)), NULL);
+                                          gtk_widget_get_screen (GTK_WIDGET (browser)), NULL, TRUE);
           g_object_unref (application);
         }
       else if (open_in == OPEN_IN_TAB)
@@ -1717,7 +1717,8 @@ thunar_shortcuts_view_poke_device_finish (ThunarBrowser *browser,
                                           ThunarDevice  *device,
                                           ThunarFile    *mount_point,
                                           GError        *error,
-                                          gpointer       user_data)
+                                          gpointer       user_data,
+                                          gboolean       cancelled)
 {
   gchar        *device_name;
   GtkTreeModel *model;
@@ -1726,7 +1727,11 @@ thunar_shortcuts_view_poke_device_finish (ThunarBrowser *browser,
   _thunar_return_if_fail (THUNAR_IS_SHORTCUTS_VIEW (browser));
   _thunar_return_if_fail (THUNAR_IS_DEVICE (device));
 
-  if (error == NULL)
+  if (cancelled)
+    {
+      /* do nothing */
+    }
+  else if (error == NULL)
     {
       thunar_browser_poke_file (browser, mount_point, GTK_WIDGET (browser),
                                 thunar_shortcuts_view_poke_file_finish,
